==> 3.5.12-core.tar: kdepim/kaddressbook/imeditwidget.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2002 Mike Pilone <mpilone@slac.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef IMEDITWIDGET_H
#define IMEDITWIDGET_H

#include <kabc/addressee.h>
#include <kdialogbase.h>

class TQButtonGroup;
class TQCheckBox;
class TQListView;
class TQTextEdit;
class TQToolButton;

class KComboBox;
class KLineEdit;
class KListView;

/**
  This widget displays a list box of the instant messaging addresses as well as buttons
  to manipulate them (up, down, add, remove).
*/
class IMEditWidget : public QWidget
{
  Q_OBJECT

  public:
    IMEditWidget(TQWidget *parent, KABC::Addressee &addr, const char *name = 0 );
    ~IMEditWidget();

    void setIMs( const TQStringList &list );
    TQStringList ims();

    void setPreferredIM( const TQString &addr );
    TQString preferredIM();
    void setReadOnly( bool readOnly );

  signals:
    void modified();

  private slots:
    void edit();
    void textChanged( const TQString& );

  private:
    KLineEdit *mIMEdit;
    TQPushButton *mEditButton;
    TQStringList mIMList;
    bool mReadOnly;
    KABC::Addressee &mAddressee;
};


#endif

==> 3.5.13-core.tar: kdepim/kaddressbook/imeditwidget.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2002 Mike Pilone <mpilone@slac.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of TQt, and distribute the resulting executable,
    without including the source code for TQt in the source distribution.
*/

#ifndef IMEDITWIDGET_H
#define IMEDITWIDGET_H

#include <kabc/addressee.h>
#include <kdialogbase.h>

class TQButtonGroup;
class TQCheckBox;
class TQListView;
class TQTextEdit;
class TQToolButton;

class KComboBox;
class KLineEdit;
class KListView;

/**
  This widget displays a list box of the instant messaging addresses as well as buttons
  to manipulate them (up, down, add, remove).
*/
class IMEditWidget : public TQWidget
{
  Q_OBJECT
  TQ_OBJECT

  public:
    IMEditWidget(TQWidget *parent, KABC::Addressee &addr, const char *name = 0 );
    ~IMEditWidget();

    void setIMs( const TQStringList &list );
    TQStringList ims();

    void setPreferredIM( const TQString &addr );
    TQString preferredIM();
    void setReadOnly( bool readOnly );

  signals:
    void modified();

  private slots:
    void edit();
    void textChanged( const TQString& );

  private:
    KLineEdit *mIMEdit;
    TQPushButton *mEditButton;
    TQStringList mIMList;
    bool mReadOnly;
    KABC::Addressee &mAddressee;
};


#endif
